# aastex

[![tests](https://github.com/sun-data/aastex/actions/workflows/tests.yml/badge.svg)](https://github.com/sun-data/aastex/actions/workflows/tests.yml)
[![codecov](https://codecov.io/gh/sun-data/aastex/graph/badge.svg?token=c9VYZtRAO8)](https://codecov.io/gh/sun-data/aastex)
[![Black](https://github.com/sun-data/aastex/actions/workflows/black.yml/badge.svg)](https://github.com/sun-data/aastex/actions/workflows/black.yml)

A Python wrapper around the AASTeX Latex package
